AsyncBody

Struct AsyncBody 

pub struct AsyncBody(pub Inner);
Tuple Fields

0: Inner

Implementations

Source

impl AsyncBody

pub fn empty() -> Self

Create a new empty body.

An empty body represents the absence of a body, which is semantically different than the presence of a body of zero length.

pub fn from_reader<R>(read: R) -> Self
where R: AsyncRead + Send + Sync + 'static,

Create a streaming body that reads from the given reader.

pub fn from_bytes(bytes: Bytes) -> Self